@@ -27,7 +27,7 @@ use_plugin("core")
 
 
 @init
-def initialized_install_dependencies_plugin(project):
+def initialize_install_dependencies_plugin(project):
     project.set_property_if_unset("dir_install_logs", "$dir_logs/install_dependencies")
     project.set_property_if_unset("install_dependencies_index_url", None)
     project.set_property_if_unset("install_dependencies_extra_index_url", None)
@@ -82,7 +82,7 @@ def install_dependency(logger, project, dependency):
     logger.info("Installing dependency '%s'%s", dependency.name, " from %s" % dependency.url if dependency.url else "")
     log_file = project.expand_path("$dir_install_logs", dependency.name)
 
-    pip_command_line = "pip install {0}'{1}'".format(build_pip_install_options(project), as_pip_argument(dependency))
+    pip_command_line = "pip install {0}'{1}'".format(build_pip_install_options(project, dependency), as_pip_argument(dependency))
     exit_code = execute_command(pip_command_line, log_file, shell=True)
     if exit_code != 0:
         if project.get_property("verbose"):
@@ -94,7 +94,7 @@ def install_dependency(logger, project, dependency):
                                        log_file)
 
 
-def build_pip_install_options(project):
+def build_pip_install_options(project, dependency):
     options = []
     if project.get_property("install_dependencies_index_url"):
         options.append("--index-url " + project.get_property("install_dependencies_index_url"))
@@ -104,6 +104,12 @@ def build_pip_install_options(project):
     if project.get_property("install_dependencies_upgrade"):
         options.append("--upgrade")
 
+    if _pip_disallows_insecure_packages_by_default():
+        for insecure_dependency in project.get_property("install_dependencies_insecure_installation", []):
+            arguments_for_insecure_installation = ["--allow-unverified", insecure_dependency,
+                                                   "--allow-external", insecure_dependency]
+            options.extend(arguments_for_insecure_installation)
+
     result = " ".join(options)
     if result:
         result += " "
@@ -114,3 +120,10 @@ def as_pip_argument(dependency):
     if dependency.url:
         return dependency.url
     return "{0}{1}".format(dependency.name, build_dependency_version_string(dependency))
+
+
+def _pip_disallows_insecure_packages_by_default():
+    import pip
+    # (2014-01-01) BACKWARD INCOMPATIBLE pip no longer will scrape insecure external urls by default
+    # nor will it install externally hosted files by default
+    return pip.__version__ >= '1.5'
