@@ -74,7 +74,7 @@ def run_integration_tests_sequentially(project, logger):
 
     total_time.stop()
 
-    return (report_items, total_time)
+    return report_items, total_time
 
 
 def run_integration_tests_in_parallel(project, logger):
@@ -139,7 +139,7 @@ def run_integration_tests_in_parallel(project, logger):
 
     total_time.stop()
 
-    return (reports.items, total_time)
+    return reports.items, total_time
 
 
 def discover_integration_tests(source_path, suffix=".py"):
@@ -202,13 +202,23 @@ def prepare_reports_directory(project):
 
 
 def run_single_test(logger, project, reports_dir, test, output_test_names=True):
+    additional_integrationtest_commandline_text = project.get_property("integrationtest_additional_commandline", "")
+
+    if additional_integrationtest_commandline_text:
+        additional_integrationtest_commandline = tuple(additional_integrationtest_commandline_text.split(" "))
+    else:
+        additional_integrationtest_commandline = ()
+
     name, _ = os.path.splitext(os.path.basename(test))
+
     if output_test_names:
         logger.info("Running integration test %s", name)
 
     env = prepare_environment(project)
     test_time = Timer.start()
     command_and_arguments = (sys.executable, test)
+    command_and_arguments += additional_integrationtest_commandline
+
     report_file_name = os.path.join(reports_dir, name)
     error_file_name = report_file_name + ".err"
     return_code = execute_command(
@@ -332,11 +342,11 @@ class TaskPoolProgress(object):
 
     @property
     def waiting_tasks_count(self):
-        return (self.total_tasks_count - self.finished_tasks_count - self.running_tasks_count)
+        return self.total_tasks_count - self.finished_tasks_count - self.running_tasks_count
 
     @property
     def is_finished(self):
-        return (self.finished_tasks_count == self.total_tasks_count)
+        return self.finished_tasks_count == self.total_tasks_count
 
     @property
     def can_be_displayed(self):
